@@ -59,15 +59,7 @@ QProcessEnvironment engines::getEnvPaths() const
 
 	const auto& basePath = m_enginePaths.binPath() ;
 
-	auto separator = [ & ](){
-
-		if( utility::platformIsLikeWindows() ){
-
-			return ";" ;
-		}else{
-			return ":" ;
-		}
-	}() ;
+	auto separator = utility::platformIsLikeWindows() ? ";" : ":" ;
 
 	QString s ;
 
@@ -830,11 +822,11 @@ void engines::engine::updateOptions()
 	m_defaultSubtitleDownloadOptions  = this->toStringList( m_jsonObject.value( "DefaultSubtitleDownloadOptions" ) ) ;
 }
 
-QJsonObject engines::engine::getCmd( const QJsonObject& cmd )
+QJsonObject engines::engine::getCmd( const QJsonObject& cmd,const QString& arc )
 {
 	if( utility::platformIsWindows() ){
 
-		return cmd.value( "Windows" ).toObject() ;
+		return cmd.value( "Windows" ).toObject().value( arc ).toObject() ;
 	}else{
 		if( utility::platformIsOSX() ){
 
@@ -842,46 +834,76 @@ QJsonObject engines::engine::getCmd( const QJsonObject& cmd )
 
 			if( !m.isEmpty() ){
 
-				return m ;
+				return m.value( arc ).toObject() ;
 			}
 		}
 
-		return cmd.value( "Generic" ).toObject() ;
+		return cmd.value( "Generic" ).toObject().value( arc ).toObject() ;
 	}
 }
 
-engines::engine::cmd engines::engine::getCommands( const QJsonObject& cmd )
+engines::engine::cmd engines::engine::getCommands( const QString& engineName,const QJsonObject& obj )
 {
-	auto obj = [ & ](){
+	auto cmd = obj.value( "Cmd" ).toObject() ;
 
-		utility::CPU cpu ;
+	utility::CPU cpu ;
 
-		if( cpu.x86_32() ){
+	if( utility::platformIsWindows7() && engineName == "yt-dlp" ){
 
-			return this->getCmd( cmd ).value( "x86" ).toObject() ;
+		auto url = obj.value( "DownloadUrlWin7" ).toString() ;
 
-		}else if( cpu.x86_64() ){
+		auto arc = cpu.x86_64() ? "win7amd64" : "win7x86" ;
 
-			return this->getCmd( cmd ).value( "amd64" ).toObject() ;
+		return { this->getCmd( cmd,arc ),url,*this } ;
+	}
 
-		}else if( cpu.aarch64() ){
+	QString url ;
 
-			auto m = this->getCmd( cmd ).value( "aarch64" ).toObject() ;
+	if( utility::platformIsOSX() ){
 
-			if( !m.isEmpty() ){
+		url = obj.value( "DownloadUrlMAC" ).toString() ;
 
-				return m ;
-			}
+		if( url.isEmpty() ){
+
+			url = obj.value( "DownloadUrl" ).toString() ;
+		}
+	}else{
+		url = obj.value( "DownloadUrl" ).toString() ;
+	}
+
+	if( cpu.x86_32() ){
+
+		auto m = this->getCmd( cmd,"x86" ) ;
+
+		if( !m.isEmpty() ){
+
+			return { m,url,*this } ;
 		}
 
-		return this->getCmd( cmd ).value( "amd64" ).toObject() ;
-	}() ;
+	}else if( cpu.x86_64() ){
 
-	auto m = obj.value( "Name" ).toString() ;
+		return { this->getCmd( cmd,"amd64" ),url,*this } ;
 
-	auto s = this->toStringList( obj.value( "Args" ).toArray() ) ;
+	}else if( cpu.aarch64() ){
 
-	return { m,s,s.size() == 1 } ;
+		auto m = this->getCmd( cmd,"aarch64" ) ;
+
+		if( !m.isEmpty() ){
+
+			return { m,url,*this } ;
+		}
+	}
+
+	return { this->getCmd( cmd,"amd64" ),url,*this } ;
+}
+
+engines::engine::cmd::cmd( const QJsonObject& obj,
+			   const QString& url,
+			   const engines::engine& engine ) :
+	m_commandName( obj.value( "Name" ).toString() ),
+	m_downloadUrl( url ),
+	m_args( engine.toStringList( obj.value( "Args" ).toArray() ) )
+{
 }
 
 QJsonObject engines::engine::getOpts( const util::Json& e ) const
@@ -909,16 +931,6 @@ QJsonObject engines::engine::getOpts( const util::Json& e ) const
 		obj.insert( "DownloadUrl",svtplay_dl::downloadUrl() ) ;
 	}
 
-	if( utility::platformIsOSX() ){
-
-		auto m = obj.value( "DownloadUrlMAC" ).toString() ;
-
-		if( !m.isEmpty() ){
-
-			obj.insert( "DownloadUrl",m ) ;
-		}
-	}
-
 	return obj ;
 }
 
@@ -938,8 +950,7 @@ engines::engine::engine( Logger& logger,
 	m_versionArgument( m_jsonObject.value( "VersionArgument" ).toString() ),
 	m_name( m_jsonObject.value( "Name" ).toString() ),
 	m_configVersion( m_jsonObject.value( "Version" ).toString() ),
-	m_exeFolderPath( m_jsonObject.value( "BackendPath" ).toString() ),
-	m_downloadUrl( m_jsonObject.value( "DownloadUrl" ).toString() )
+	m_exeFolderPath( m_jsonObject.value( "BackendPath" ).toString() )
 {
 	auto defaultPath = utility::stringConstants::defaultPath() ;
 	auto backendPath = utility::stringConstants::backendPath() ;
@@ -949,15 +960,17 @@ engines::engine::engine( Logger& logger,
 		m_exeFolderPath = ePaths.binPath() ;
 	}
 
-	auto m = this->getCommands( m_jsonObject.value( "Cmd" ).toObject() ) ;
+	auto m = this->getCommands( m_name,m_jsonObject ) ;
 
-	m_commandName = m.name ;
+	m_commandName = m.commandName() ;
 
-	if( m.noCheckArgs ){
+	m_downloadUrl = m.downloadUrl() ;
+
+	if( m.noCheckArgs() ){
 
 		this->parseMultipleCmdArgs( logger,engines,ePaths,id ) ;
 	}else{
-		this->parseMultipleCmdArgs( m.args,backendPath,logger,ePaths,engines,id ) ;
+		this->parseMultipleCmdArgs( m.args(),backendPath,logger,ePaths,engines,id ) ;
 	}
 }
 
@@ -1025,7 +1038,7 @@ void engines::engine::parseMultipleCmdArgs( Logger& logger,
 	}
 }
 
-void engines::engine::parseMultipleCmdArgs( QStringList& cmdNames,
+void engines::engine::parseMultipleCmdArgs( QStringList cmdNames,
 					    const QString& backendPath,
 					    Logger& logger,
 					    const enginePaths& ePaths,
