@@ -1447,20 +1447,39 @@ public:
 		void setPermissions( const QString& ) const ;
 		void updateOptions() ;
 		QStringList toStringList( const QJsonValue&,bool = false ) const ;
-		QJsonObject getCmd( const QJsonObject& ) ;
+		QJsonObject getCmd( const QJsonObject&,const QString& ) ;
 
-		struct cmd
+		class cmd
 		{
-			QString name ;
-			QStringList args ;
-			bool noCheckArgs ;
+		public:
+			cmd( const QJsonObject&,const QString&,const engines::engine& ) ;
+			const QString& commandName() const
+			{
+				return m_commandName ;
+			}
+			const QString& downloadUrl() const
+			{
+				return m_downloadUrl ;
+			}
+			const QStringList& args() const
+			{
+				return m_args ;
+			}
+			bool noCheckArgs() const
+			{
+				return m_args.size() == 1 ;
+			}
+		private:
+			QString m_commandName ;
+			QString m_downloadUrl ;
+			QStringList m_args ;
 		} ;
 
-		engines::engine::cmd getCommands( const QJsonObject& ) ;
+		engines::engine::cmd getCommands( const QString&,const QJsonObject& ) ;
 
 		void parseMultipleCmdArgs( Logger& logger,const engines& engines,const enginePaths&,int ) ;
 
-		void parseMultipleCmdArgs( QStringList&,
+		void parseMultipleCmdArgs( QStringList,
 					   const QString&,
 					   Logger& logger,
 					   const enginePaths& ePaths,
