@@ -28,7 +28,7 @@ public:
 	static const char * testData() ;
 
 	~lux() override ;
-	lux( const engines&,const engines::engine&,QJsonObject&,const QString& downloadFolder ) ;
+	lux( const engines&,const engines::engine&,QJsonObject& ) ;
 
 	class lux_dlFilter : public engines::engine::baseEngine::filter
 	{
@@ -54,7 +54,7 @@ public:
 
 	engines::engine::baseEngine::DataFilter Filter( int ) override ;
 
-	engines::engine::baseEngine::optionsEnvironment setProxySetting( QStringList&,const QString& ) override ;
+	void setProxySetting( engines::engine::baseEngine::optionsEnvironment&,QStringList&,const QString& ) override ;
 
 	std::vector< engines::engine::baseEngine::mediaInfo > mediaProperties( Logger&,const QByteArray& ) override ;
 
@@ -66,7 +66,7 @@ public:
 				       bool,
 				       const QStringList&) override ;
 
-	engines::engine::baseEngine::FilterOutPut filterOutput() override ;
+	engines::engine::baseEngine::FilterOutPut filterOutput( int ) override ;
 
 	QString updateTextOnCompleteDownlod( const QString& uiText,
 					     const QString& bkText,
