@@ -28,9 +28,10 @@ public:
 				 const engines::enginePaths& enginePath ) ;
 	~quickjs() ;
 	engines::metadata parseJsonDataFromGitHub( const QJsonDocument& ) override ;
-	std::vector< engines::engine::baseEngine::removeFilesStatus > removeFiles( const QStringList&,const QString& ) override ;
+	engines::engine::baseEngine::removeFilesStatus removeFiles( const QStringList&,const QString& ) override ;
 	bool foundNetworkUrl( const QString& s ) override ;
 	QString parseVersionInfo( const utils::qprocess::outPut& ) override ;
 	quickjs( const engines&,const engines::engine&,QJsonObject& ) ;
 private:
+	QString namePrefix() ;
 };
