@@ -209,6 +209,17 @@ public:
 		{
 			m_processOutputs.clear() ;
 		}
+		void clear( int id )
+		{
+			for( auto it = m_processOutputs.begin() ; it != m_processOutputs.end() ; it++ ){
+
+				if( it->processId() == id ){
+
+					it->entries().clear() ;
+					break ;
+				}
+			}
+		}
 		class QByteArrayList
 		{
 		public:
@@ -322,6 +333,15 @@ public:
 		{
 			return this->join( "\n" ) ;
 		}
+		QByteArray join( const QByteArray& joiner,int id ) const ;
+		QByteArray toLine( int id ) const
+		{
+			return this->join( "",id ) ;
+		}
+		QByteArray toLines( int id ) const
+		{
+			return this->join( "\n",id ) ;
+		}
 		void removeExtraLogs() ;
 		bool removeFirstFinished() ;
 		class ProcessData
@@ -391,16 +411,42 @@ public:
 		{
 			return m_processOutputs.rbegin()->doneDownloading() ;
 		}
-		template< typename Function >
-		void replaceOrAdd( const QByteArray& text,int id,const Function& function )
+		template< typename Filter >
+		void replaceOrAdd( const Filter& filter )
 		{
-			_replaceOrAdd( text,id,function ) ;
+			_replaceOrAdd( filter ) ;
 		}
 		void add( const QByteArray& text,int id )
 		{
-			auto _false = []( const QByteArray& ){ return false ; } ;
+			class Filter
+			{
+			public:
+				Filter( int id,const QByteArray& arr ) :
+					m_id( id ),m_text( arr )
+				{
+				}
+				int id() const
+				{
+					return m_id ;
+				}
+				const QByteArray& text() const
+				{
+					return m_text ;
+				}
+				bool skip( const QByteArray& ) const
+				{
+					return false ;
+				}
+				bool replace( const QByteArray& ) const
+				{
+					return false ;
+				}
+			private:
+				int m_id ;
+				const QByteArray& m_text ;
+			} ;
 
-			_replaceOrAdd( text,id,_false ) ;
+			_replaceOrAdd( Filter( id,text ) ) ;
 		}
 		class YtDlpData
 		{
@@ -489,14 +535,14 @@ public:
 	private:
 		void manageLogSize( std::vector< Logger::Data::processOutput::outputEntry >& ) ;
 		bool doneDownloadingText( const QByteArray& data ) ;
-		template< typename Function >
-		void _replaceOrAdd( const QByteArray& text,int id,const Function& function )
+		template< typename Filter >
+		void _replaceOrAdd( const Filter& filter )
 		{
 			for( auto it = m_processOutputs.rbegin() ; it != m_processOutputs.rend() ; it++ ){
 
-				if( it->processId() == id ){
+				if( it->processId() == filter.id() ){
 
-					if( this->doneDownloadingText( text ) ){
+					if( this->doneDownloadingText( filter.text() ) ){
 
 						it->setDoneDownloading() ;
 					}
@@ -505,19 +551,22 @@ public:
 
 					if( ee.empty() ){
 
-						ee.emplace_back( text ) ;
+						ee.emplace_back( filter.text() ) ;
 					}else{
 						auto iter = ee.rbegin() ;
 
 						const auto& s = iter->text() ;
 
-						if( function( s ) ){
+						if( filter.replace( s ) ){
 
-							iter->replace( text ) ;
+							iter->replace( filter.text() ) ;
 						}else{
 							this->manageLogSize( ee ) ;
 
-							ee.emplace_back( text ) ;
+							if( !filter.skip( filter.text() ) ){
+
+								ee.emplace_back( filter.text() ) ;
+							}
 						}
 					}
 
@@ -525,7 +574,10 @@ public:
 				}
 			}
 
-			m_processOutputs.emplace_back( id,text ) ;
+			if( !filter.skip( filter.text() ) ){
+
+				m_processOutputs.emplace_back( filter.id(),filter.text() ) ;
+			}
 		}
 		std::list< Logger::Data::processOutput > m_processOutputs ;
 		bool m_mainLogger ;
@@ -553,9 +605,35 @@ public:
 	}
 	void logError( const QByteArray& data,int id )
 	{
-		auto function = []( const QByteArray& ){ return false ; } ;
+		class Filter
+		{
+		public:
+			Filter( int id,const QByteArray& data ) :
+				m_id( id ),m_text( "[media-downloader][std error] " + data )
+			{
+			}
+			int id() const
+			{
+				return m_id ;
+			}
+			const QByteArray& text() const
+			{
+				return m_text ;
+			}
+			bool skip( const QByteArray& ) const
+			{
+				return false ;
+			}
+			bool replace( const QByteArray& ) const
+			{
+				return false ;
+			}
+		private:
+			int m_id ;
+			QByteArray m_text ;
+		} ;
 
-		m_processOutPuts.replaceOrAdd( "[media-downloader][std error] " + data,id,function ) ;
+		m_processOutPuts.replaceOrAdd( Filter( id,data ) ) ;
 
 		this->update() ;
 	}
@@ -564,7 +642,8 @@ public:
 		this->setMaxProcessLog( static_cast< int >( s ) ) ;
 	}
 	void setMaxProcessLog( int s ) ;
-	void showLogWindow() ;
+	void showLogWindow( int ) ;
+	void showAllLogs() ;
 	void reTranslateLogWindow() ;
 	void updateView( bool e ) ;
 	const std::vector< QByteArray >& fileNames()
@@ -575,7 +654,7 @@ public:
 	Logger& operator=( const Logger& ) = delete ;
 	Logger( Logger&& ) = delete ;
 	Logger& operator=( Logger&& ) = delete ;
-private:
+private:	
 	void update() ;
 	logWindow m_logWindow ;
 	QPlainTextEdit& m_textEdit ;
@@ -583,6 +662,20 @@ private:
 	bool m_updateView = false ;
 	settings& m_settings ;
 	int m_maxProcessLog ;
+	int m_id = -1 ;
+
+	class meaw : public QObject
+	{
+	public:
+		meaw( Logger& p ) : m_parent( p )
+		{
+		}
+		bool eventFilter( QObject *,QEvent * ) override ;
+	private:
+		Logger& m_parent ;
+	} ;
+
+	meaw m_qobj ;
 } ;
 
 class LoggerWrapper
