@@ -1292,10 +1292,6 @@ Per maggiori dettagli vedi la GNU (General Public License).</translation>
 </context>
 <context>
     <name>logWindow</name>
-    <message>
-        <source>Clear</source>
-        <translation>Azzera</translation>
-    </message>
     <message>
         <source>Close</source>
         <translation>Chiudi</translation>
@@ -1304,6 +1300,10 @@ Per maggiori dettagli vedi la GNU (General Public License).</translation>
         <source>Log Window</source>
         <translation>Finestra registro eventi</translation>
     </message>
+    <message>
+        <source>Show All</source>
+        <translation>Visualizza tutto</translation>
+    </message>
 </context>
 <context>
     <name>playlistdownloader</name>
