@@ -1298,8 +1298,8 @@ Exampe 2: ${gateway}:8080</source>
         <translation>닫기</translation>
     </message>
     <message>
-        <source>Clear</source>
-        <translation>지우기</translation>
+        <source>Show All</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
